@@ -20,7 +20,7 @@ def mark_all_stale(course_key, users=None):
     """
     Mark the specified enrollments as stale for all blocks.
     """
-    if isinstance(course_key, six.text_type):
+    if isinstance(course_key, six.string_types):
         course_key = CourseKey.from_string(course_key)
     usernames = users or [user.username for user in get_active_users(course_key)]
     stale_objects = [StaleCompletion(username=username, course_key=course_key, force=True) for username in usernames]
